@@ -139,7 +139,7 @@ class ADObject:
                 self.policy_enablement_state_map[policy_dn.lower()] = enablement_enum
 
     def get(self, attribute_name: str, unpack_one_item_lists=False):
-        """ Get an attribute about the group that isn't explicitly tracked as a member """
+        """ Get an attribute about the object that isn't explicitly tracked as a member """
         val = self.all_attributes.get(attribute_name)
         # there's a lot of 1-item lists from the ldap3 library
         if isinstance(val, list) and len(val) == 1 and unpack_one_item_lists:
